@@ -50,7 +50,7 @@ def is_series_bool(series: pd.Series) -> bool:
     if is_bool_dtype(series):
         return True
 
-    def is_nan(value):  # pylint: disable=inconsistent-return-statements
+    def is_nan(value):
         try:
             if np.isnan(value):
                 return True
@@ -295,7 +295,6 @@ def reorder_categories(categorical: Union[pd.Series, pd.Categorical],
     return results
 
 
-# pylint: disable=too-many-arguments
 def top_n_categories(categorical: Union[pd.Series, pd.Categorical],
                      top_n: int = 5,
                      other_category: str = 'Other',
@@ -521,7 +520,7 @@ def numeric_summary(dataframe: pd.DataFrame,
             bar(subset=['% Nulls'], color=color.BAD, vmin=0, vmax=1). \
             bar(subset=['% Zeros'], color=color.GRAY, vmin=0, vmax=1). \
             bar(subset=['Coef of Var'], color=color.GRAY, vmin=0, vmax=1). \
-            bar(subset=['Skewness'], color=color.GRAY,  align='mid', vmin=-2, vmax=2)
+            bar(subset=['Skewness'], color=color.GRAY, align='mid', vmin=-2, vmax=2)
 
     return results
 
@@ -580,7 +579,10 @@ def non_numeric_summary(dataframe: pd.DataFrame,
         return counts.index[0] if len(counts) > 0 else None
 
     def chop_string(value):
-        if isinstance(value, str) and len(value) > unique_freq_value_max_chars:
+        if not isinstance(value, str):
+            value = str(value)
+
+        if len(value) > unique_freq_value_max_chars:
             value = value[0:unique_freq_value_max_chars] + '[...]'
         return value
 
@@ -612,9 +614,10 @@ def non_numeric_summary(dataframe: pd.DataFrame,
     if return_style:
         results = pstyle.html_escape_dataframe(results)
         results = results.style.format({
-                '% Nulls': '{:,.1%}'.format,
-                '% Unique': '{:,.1%}'.format
-            }). \
+            '% Nulls': '{:,.1%}'.format,
+            '% Unique': '{:,.1%}'.format
+        })
+        results = results. \
             pipe(pstyle.format,
                  subset=['# of Non-Nulls', '# of Nulls'],
                  round_by=0). \
@@ -675,7 +678,6 @@ def value_frequency(series: pd.Series, sort_by_frequency=True) -> pd.DataFrame:
     return results
 
 
-# pylint: disable=too-many-locals, too-many-branches, too-many-statements
 def count_groups(dataframe: pd.DataFrame,
                  group_1: str,
                  group_2: Optional[str] = None,
@@ -853,6 +855,6 @@ def count_groups(dataframe: pd.DataFrame,
                 format(subset=idx[:, idx[(group_2, 'Sum Perc')]], precision=4, formatter='{:,.2%}'.format). \
                 bar(subset=idx[:, idx[(group_2, 'Sum Perc')]], vmin=0, vmax=1, color=color.GRAY)
 
-    final = final.hide_index()
+    final = final.hide(axis='index')
 
     return final
